Summary:	A screen manager that supports multiple logins on one terminal
Name:		screen
Version:	5.0.1
Release: 	%mkrel 1
License:	GPLv2+
Group:		Terminals
URL:		https://www.gnu.org/software/screen/
Source0:	https://ftp.gnu.org/gnu/screen/screen-%{version}.tar.gz
Source1:	screen.pam
# correct the location of various files in man page and info page
# not sent upstream
Patch0:		screen-5.0.0-fix-utmp.patch
# add U as default binding to switch to utf8, in /etc/screenrc
# not to send upstream
Patch1:		screen-4.0.2-screenrc-utf8-switch.patch
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	utempter-devel
BuildRequires:	texinfo
BuildRequires:	pam-devel

%description
The screen utility allows you to have multiple logins on just one
terminal.  Screen is useful for users who telnet into a machine or
are connected via a dumb terminal, but want to use more than just
one login.

Install the screen package if you need a screen manager that can
support multiple logins on one terminal.

%prep
%autosetup -p1

%build
autoreconf -fi
# 5 is tty group
%configure --enable-colors256 \
           --enable-pam \
           --with-pty-mode=0620 \
           --with-pty-group=5 \
           --enable-telnet \
           --with-sys-screenrc=%{_sysconfdir}/screenrc \
           --with-socket-dir=%{_rundir}/screen

perl -pi -e 's|.*#undef HAVE_BRAILLE.*|#define HAVE_BRAILLE 1|' config.h

perl -pi -e 's|/usr/local/etc/screenrc|%{_sysconfdir}/screenrc|' etc/etcscreenrc doc/*
perl -pi -e 's|/local/etc/screenrc|%{_sysconfdir}/screenrc|' doc/*

%make_build

%install
%make_install SCREENENCODINGS=%{_datadir}/screen/utf8encodings/

( cd %{buildroot}%{_bindir} && {
	rm -f screen.old screen
	mv screen-%{version} screen
  }
)
mkdir -p %{buildroot}%{_sysconfdir}/skel
install -c -m 0644 etc/etcscreenrc %{buildroot}%{_sysconfdir}/screenrc
install -c -m 0644 etc/screenrc %{buildroot}%{_sysconfdir}/skel/.screenrc

# pam.d config
install -D -p -m 0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/pam.d/screen

mkdir -p %{buildroot}%{_tmpfilesdir}
cat <<EOF > %{buildroot}%{_tmpfilesdir}/screen.conf
# screen needs directory in /run
d %{_rundir}/screen 0775 root screen
EOF

%pre
%_pre_groupadd %{name}

%post
%_tmpfilescreate %{name}

%files
%doc README doc/FAQ doc/README.DOTSCREEN ChangeLog
%license COPYING
%attr(2755,root,screen) %{_bindir}/screen
%config(noreplace) %{_sysconfdir}/screenrc
%config(noreplace) %{_sysconfdir}/pam.d/screen
%attr(644,root,root) %config(noreplace) %{_sysconfdir}/skel/.screenrc
%{_tmpfilesdir}/screen.conf
%{_datadir}/screen/
%{_mandir}/man1/screen.1*


%changelog
* Fri May 16 2025 daviddavid <daviddavid> 5.0.1-1.mga10
+ Revision: 2183962
- new version: 5.0.1

* Thu Nov 21 2024 daviddavid <daviddavid> 5.0.0-1.mga10
+ Revision: 2118063
- new version: 5.0.0

* Thu Sep 21 2023 daviddavid <daviddavid> 4.9.1-1.mga10
+ Revision: 1989235
- new version: 4.9.1

* Thu Jan 19 2023 wally <wally> 4.9.0-4.mga9
+ Revision: 1934386
- enable pam support to authenticate users when locking screen

* Thu Jan 19 2023 wally <wally> 4.9.0-3.mga9
+ Revision: 1934377
- install screen with setgid-screen
- move default socket dir from $HOME/tmp to /run/screen
  (default location can be still overriden by exporting SCREENDIR=$HOME/tmp)
- fix /var/run occurrences to /run in Patch0

* Fri Mar 18 2022 danf <danf> 4.9.0-2.mga9
+ Revision: 1797614
- Patch a typo that caused a compile failure
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild
+ luigiwalser <luigiwalser>
- 4.9.0
- remove upstream CVE patch

* Sat Feb 27 2021 daviddavid <daviddavid> 4.8.0-3.mga9
+ Revision: 1692553
- add patch to fix CVE-2021-26937 (mga#28390)

* Thu Feb 20 2020 umeabot <umeabot> 4.8.0-2.mga8
+ Revision: 1546966
- Mageia 8 Mass Rebuild

* Thu Feb 06 2020 daviddavid <daviddavid> 4.8.0-1.mga8
+ Revision: 1487375
- new version: 4.8.0
+ wally <wally>
- replace deprecated %%configure2_5x

* Wed Oct 02 2019 daviddavid <daviddavid> 4.7.0-1.mga8
+ Revision: 1448892
- new version: 4.7.0

* Mon Sep 03 2018 tv <tv> 4.6.2-2.mga7
+ Revision: 1256415
- rely on filetriggers for info system (mga#23482)

* Tue Feb 20 2018 kekepower <kekepower> 4.6.2-1.mga7
+ Revision: 1203435
- Update to version 4.6.2

* Sun Oct 01 2017 cjw <cjw> 4.6.1-1.mga7
+ Revision: 1162075
- 4.6.1

* Sun Feb 26 2017 luigiwalser <luigiwalser> 4.5.1-1.mga6
+ Revision: 1087925
- 4.5.1
- add patch to fix texinfo syntax mistake in 4.5.1
+ tv <tv>
- do not package outdated NEWS

* Wed Jan 18 2017 luigiwalser <luigiwalser> 4.5.0-1.mga6
+ Revision: 1082408
- 4.5.0

* Thu Aug 11 2016 luigiwalser <luigiwalser> 4.4.0-1.mga6
+ Revision: 1045593
- 4.4.0
- remove upstreamed CVE-2015-6806 patch

* Mon Jan 11 2016 luigiwalser <luigiwalser> 4.3.1-1.mga6
+ Revision: 921720
- 4.3.1
- remove upstreamed patches 12, 13, and 15

* Fri Sep 04 2015 luigiwalser <luigiwalser> 4.2.1-4.mga6
+ Revision: 872761
- add patches from debian to fix security issues including CVE-2015-6806

* Wed Oct 15 2014 umeabot <umeabot> 4.2.1-3.mga5
+ Revision: 739575
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 4.2.1-2.mga5
+ Revision: 689078
- Mageia 5 Mass Rebuild

* Wed Apr 30 2014 guillomovitch <guillomovitch> 4.2.1-1.mga5
+ Revision: 618951
- new version 4.2.1
- update patches 4 and 12
- drop obsoletes patches 6, 7, 9, 13, 14 and 15

* Mon Feb 10 2014 jquelin <jquelin> 4.0.3-15.mga5
+ Revision: 588153
- reverting, need to be owner of SCREENDIR

* Mon Feb 10 2014 jquelin <jquelin> 4.0.3-14.mga5
+ Revision: 588142
- respect system policy for screen temp directory

* Sat Oct 19 2013 umeabot <umeabot> 4.0.3-13.mga4
+ Revision: 532685
- Mageia 4 Mass Rebuild

* Thu Aug 22 2013 luigiwalser <luigiwalser> 4.0.3-12.mga4
+ Revision: 469239
- add patch from mancha to fix null pointer deref with glibc 2.17

* Mon Jan 14 2013 umeabot <umeabot> 4.0.3-11.mga3
+ Revision: 381897
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Jun 10 2012 blino <blino> 4.0.3-10.mga3
+ Revision: 259477
- rebuild to get info pages as xz instead of lzma
+ guillomovitch <guillomovitch>
- spec cleanup

* Sat Jan 08 2011 blino <blino> 4.0.3-9.mga1
+ Revision: 745
- imported package screen


* Fri Dec 03 2010 Oden Eriksson <oeriksson@mandriva.com> 4.0.3-9mdv2011.0
+ Revision: 607529
- rebuild

* Sun Mar 14 2010 Oden Eriksson <oeriksson@mandriva.com> 4.0.3-8mdv2010.1
+ Revision: 519070
- rebuild

  + Michael Scherer <misc@mandriva.org>
    - remove old ppc patch as we have no ppc port, and as the patch seems to be a
      work around for some awk bug
    - remove unneeded patch coming from rh for old ia64 problem

* Mon Jun 22 2009 Lev Givon <lev@mandriva.org> 4.0.3-7mdv2010.0
+ Revision: 388108
- Refactor ia64 patch.
  Add patch to fix format-string errors.
  Enable 256 color support.

* Mon Oct 13 2008 Funda Wang <fwang@mandriva.org> 4.0.3-6mdv2009.1
+ Revision: 293321
- add patch from git to wor around vte's del key autodetect feature
  https://savannah.gnu.org/bugs/index.php?23868
- clearify the license

* Wed Jun 18 2008 Thierry Vignaud <tv@mandriva.org> 4.0.3-5mdv2009.0
+ Revision: 225411
- rebuild

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Sat Dec 22 2007 Guillaume Rousse <guillomovitch@mandriva.org> 4.0.3-4mdv2008.1
+ Revision: 137010
- no executable bit on profile scriptlet
  order prefix on profile scriptlet

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Mon Sep 24 2007 Thierry Vignaud <tv@mandriva.org> 4.0.3-3mdv2008.0
+ Revision: 92613
- fix man pages extension


* Wed Mar 14 2007 Michael Scherer <misc@mandriva.org> 4.0.3-2mdv2007.1
+ Revision: 143661
- remove patch11, was unclear and caused problem ( #29468 )

* Thu Jan 25 2007 Per Øyvind Karlsen <pkarlsen@mandriva.com> 4.0.3-1mdv2007.1
+ Revision: 113524
- new release: 4.0.3
- bump MAXSTR (string buffer size) to 4k (from 256 bytes), fixes
  status line issues with window list in status line and too many
  windows (and possibly other issues with long strings) (P11 from fedora)
- ipv6 patch (RHBZ #198410)

* Tue Oct 31 2006 Michael Scherer <misc@mandriva.org> 4.0.2-10mdv2007.1
+ Revision: 74233
- Bump release
- document the remaining patchs
-remove patch 5, screen-3.9.11-max-window-size.diff, as it does nothing except setting a constant,
  that is used nowhere in the source ( and nowhere on the internet, according to google code search and
  koders.com )
- remove Patch0, it is applied to a code snippet enclosed in a #if !defined(linux), so it doesn't
  apply to this package, unless we start to port mandriva to bsd.
- bunzip patch
- add fix for CVE-2006-4573
- Import screen

* Tue Sep 19 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 4.0.2-9mdv2007.0
- Rebuild

* Fri Jul 21 2006 Michael Scherer <misc@mandriva.org> 4.0.2-8mdv2007.0
- use mkrel
- clean buildRoot

* Mon May 08 2006 Stefan van der Eijk <stefan@eijk.nu> 4.0.2-7mdk
- rebuild for sparc

* Wed Aug 24 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 4.0.2-6mdk
- varargs fixes

* Tue Apr 26 2005 Rafael Garcia-Suarez <rgarciasuarez@mandriva.com> 4.0.2-5mdk
- Patch 8: add 'C-a U' binding to /etc/skel/.screenrc

* Tue Nov 09 2004 Rafael Garcia-Suarez <rgarciasuarez@mandrakesoft.com> 4.0.2-4mdk
- The screen profile.d script (and hence $SCREENDIR) was broken

* Thu Oct 14 2004 Olivier Thauvin <thauvin@aerov.jussieu.fr> 4.0.2-3mdk
- don't use a bash fonction to start screen profile.d, exporting SCREENDIR instead

* Wed Apr 21 2004 Olivier Blin <blino@mandrake.org> 4.0.2-2mdk
- rebuild for new libncurses

